@@ -1,5 +1,5 @@
 from Bio import SeqIO
-from Bio.SeqUtils import GC
+from Bio.SeqUtils import gc_fraction
 from mob_suite.blast import BlastRunner
 from mob_suite.blast import BlastReader
 import os, re, time
@@ -11,8 +11,7 @@ from operator import itemgetter
 from ete3 import NCBITaxa
 from mob_suite.constants import \
     MOB_TYPER_REPORT_HEADER, \
-    MGE_INFO_HEADER, \
-    ETE3DBTAXAFILE
+    MGE_INFO_HEADER
 
 
 def getAssocValues(query_list_values, look_up_key, value_key, data):
@@ -65,30 +64,6 @@ def parseMash(mash_results):
     return hits
 
 
-def getHeirarchy(taxid):
-    if not isETE3DBTAXAFILEexists(ETE3DBTAXAFILE):
-        logging.info("Did not find taxa.sqlite in {}. Initializaing ete3 taxonomy database".format(ETE3DBTAXAFILE))
-        initETE3Database()
-
-    ncbi = NCBITaxa(dbfile=ETE3DBTAXAFILE)
-    if not isETE3DBTAXAFILEexists(ETE3DBTAXAFILE):
-        logging.error(
-            "Tried ete3 init, but still was not able to find taxa.sqlite file for ete3 lib in {}. Aborting".format(
-                ETE3DBTAXAFILE))
-        return ['-', '-']
-
-    if not isinstance(taxid, int):
-        return {'names': [], 'ranks': []}
-
-    lineage = ncbi.get_lineage(taxid)
-    names = ncbi.get_taxid_translator(lineage)
-    ranks = []
-    for id in lineage:
-        ranks.append(ncbi.get_rank(id))
-
-    return {'names': names, 'ranks': names}
-
-
 def filter_invalid_taxids(taxids):
     filtered = []
     for i in taxids:
@@ -104,7 +79,7 @@ def filter_invalid_taxids(taxids):
     return filtered
 
 
-def getHeirarchy(taxid):
+def getHeirarchy(taxid,ETE3DBTAXAFILE):
     if not isETE3DBTAXAFILEexists(ETE3DBTAXAFILE):
         logging.info("Did not find taxa.sqlite in {}. Initializaing ete3 taxonomy database".format(ETE3DBTAXAFILE))
         initETE3Database()
@@ -128,7 +103,7 @@ def getHeirarchy(taxid):
     return {'names': names, 'ranks': names}
 
 
-def getTaxid(taxon):
+def getTaxid(taxon,ETE3DBTAXAFILE):
     if not isETE3DBTAXAFILEexists(ETE3DBTAXAFILE):
         logging.info("Did not find taxa.sqlite in {}. Initializaing ete3 taxonomy database".format(ETE3DBTAXAFILE))
         initETE3Database()
@@ -146,7 +121,7 @@ def getTaxid(taxon):
 
 
 
-def NamesToTaxIDs(names):
+def NamesToTaxIDs(names,ETE3DBTAXAFILE):
     if not isETE3DBTAXAFILEexists(ETE3DBTAXAFILE):
         logging.info("Did not find taxa.sqlite in {}. Initializaing ete3 taxonomy database".format(ETE3DBTAXAFILE))
         initETE3Database(ETE3DBTAXAFILE)
@@ -163,7 +138,7 @@ def NamesToTaxIDs(names):
 
 
 
-def getTaxonConvergence(taxids):
+def getTaxonConvergence(taxids,ETE3DBTAXAFILE):
     if not isETE3DBTAXAFILEexists(ETE3DBTAXAFILE):
         logging.info("Did not find taxa.sqlite in {}. Initializaing ete3 taxonomy database".format(ETE3DBTAXAFILE))
         initETE3Database(ETE3DBTAXAFILE)
@@ -231,7 +206,7 @@ def getTaxonConvergence(taxids):
     return (['-', '-'])
 
 
-def hostrange(replion_types, relaxase_types, mob_cluster_id, ncbi, lit):
+def hostrange(replion_types, relaxase_types, mob_cluster_id, ncbi, lit,ETE3DBTAXAFILE):
     host_range_predictions = {
         'observed_host_range_ncbi_name': '',
         'observed_host_range_ncbi_rank': '',
@@ -276,25 +251,25 @@ def hostrange(replion_types, relaxase_types, mob_cluster_id, ncbi, lit):
         ncbi_unique_taxids = filter_invalid_taxids(
             list(set(ncbi_replicon_taxids + ncbi_cluster_taxids + ncbi_relaxase_taxids)))
         host_range_predictions['observed_host_range_ncbi_rank'], host_range_predictions[
-            'observed_host_range_ncbi_name'] = getTaxonConvergence(ncbi_unique_taxids)
+            'observed_host_range_ncbi_name'] = getTaxonConvergence(ncbi_unique_taxids,ETE3DBTAXAFILE)
 
     # Determine taxids associated with literature
 
     lit_unique_taxids = filter_invalid_taxids(list(set(lit_replicon_taxids)))
 
     host_range_predictions['reported_host_range_lit_rank'], host_range_predictions[
-        'reported_host_range_lit_name'] = getTaxonConvergence(lit_unique_taxids)
+        'reported_host_range_lit_name'] = getTaxonConvergence(lit_unique_taxids,ETE3DBTAXAFILE)
 
     # determine overall host range
     overall_taxids = filter_invalid_taxids(list(set(ncbi_unique_taxids + lit_unique_taxids)))
     host_range_predictions['predicted_host_range_overall_rank'], host_range_predictions[
-        'predicted_host_range_overall_name'] = getTaxonConvergence(overall_taxids)
+        'predicted_host_range_overall_name'] = getTaxonConvergence(overall_taxids,ETE3DBTAXAFILE)
 
     # move host-range prediction up to family when it is at genus or species level
     if host_range_predictions['predicted_host_range_overall_rank'] == 'genus' or host_range_predictions[
         'predicted_host_range_overall_rank'] == 'species':
-        taxid = getTaxid(host_range_predictions['predicted_host_range_overall_name'])
-        heir = getHeirarchy(taxid)
+        taxid = getTaxid(host_range_predictions['predicted_host_range_overall_name'],ETE3DBTAXAFILE)
+        heir = getHeirarchy(taxid,ETE3DBTAXAFILE)
         names = heir['names']
         ranks = heir['ranks']
 
@@ -869,7 +844,7 @@ def calcFastaStatsIndividual(fasta):
         id = record.id
         seq = record.seq
         genome_size = len(seq)
-        gc = GC(seq)
+        gc = gc_fraction(seq)
         md5 = calc_md5(seq)
         stats[id] = {
             'total_length': genome_size,
@@ -892,7 +867,7 @@ def calcFastaStats(fasta):
         num_seqs += 1
         seq = seq + record.seq
     genome_size = len(seq)
-    gc = GC(seq)
+    gc = gc_fraction(seq)
     md5 = calc_md5(seq)
 
     return {
@@ -974,7 +949,7 @@ def determine_mpf_type(hits):
     return max(types, key=lambda i: types[i])
 
 
-def build_mobtyper_report(plasmid_contig_info, out_dir, outfile, seq_dict, ncbi, lit):
+def build_mobtyper_report(plasmid_contig_info, out_dir, outfile, seq_dict, ncbi, lit,ETE3DBTAXAFILE):
     mob_typer_results = {}
     for clust_id in plasmid_contig_info:
 
@@ -1008,7 +983,7 @@ def build_mobtyper_report(plasmid_contig_info, out_dir, outfile, seq_dict, ncbi,
         cluster_seq = sorted(cluster_seq,key=len)
         seq = "".join(cluster_seq)
         mob_typer_results[clust_id]['md5'] = [calc_md5(seq)]
-        mob_typer_results[clust_id]['gc'] = [GC(seq)]
+        mob_typer_results[clust_id]['gc'] = [gc_fraction(seq)]
         mob_typer_results[clust_id]['size'] = [len(seq)]
         mob_typer_results[clust_id]['num_contigs'] = len(cluster_seq)
 
@@ -1089,7 +1064,7 @@ def build_mobtyper_report(plasmid_contig_info, out_dir, outfile, seq_dict, ncbi,
         else:
             mob_cluster_id = '-'
 
-        host_range = hostrange(rep_types, relaxase_types, mob_cluster_id, ncbi, lit)
+        host_range = hostrange(rep_types, relaxase_types, mob_cluster_id, ncbi, lit,ETE3DBTAXAFILE)
 
         for field in host_range:
             mob_typer_results[clust_id][field] = host_range[field]
@@ -1305,7 +1280,7 @@ def blast_mge(contig_fasta, mge_fasta,tmp_dir, min_length, logging, min_rpp_iden
            blast_results_file=blast_results, num_threads=num_threads, logging=logging)
 
     #return empty dataframe if no blast results generated
-    if os.path.getsize(blast_results) == 0:
+    if not os.path.isfile(blast_results) or os.path.getsize(blast_results) == 0:
         return {}
 
     df = BlastReader(blast_results, logging).df
